| Title: | Language Server Protocol |
|---|---|
| Description: | An implementation of the Language Server Protocol for R. The Language Server protocol is used by an editor client to integrate features like auto completion. See <https://microsoft.github.io/language-server-protocol/> for details. |
| Authors: | Randy Lai [aut, cre], Kun Ren [ctb] |
| Maintainer: | Randy Lai <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.3.18 |
| Built: | 2026-06-01 06:53:31 UTC |
| Source: | https://github.com/reditorsupport/languageserver |
An implementation of the Language Server Protocol for R. The Language Server protocol is used by an editor client to integrate features like auto completion. See https://microsoft.github.io/language-server-protocol/ for details.
An implementation of the Language Server Protocol for R
Maintainer: Randy Lai [email protected]
Other contributors:
Kun Ren [email protected] [contributor]
Useful links:
Run the R language server
run(debug = FALSE, host = "localhost", port = NULL)run(debug = FALSE, host = "localhost", port = NULL)
debug |
set |
host |
the hostname used to create the tcp server, not used when |
port |
the port used to create the tcp server. If |
## Not run: # to use stdio languageserver::run() # to use tcp server languageserver::run(port = 8888) ## End(Not run)## Not run: # to use stdio languageserver::run() # to use tcp server languageserver::run(port = 8888) ## End(Not run)